!
! Create initial point and minimize
!

subroutine initial(n,x)

  use ff
  implicit none
  integer :: n, i
  double precision :: x(n,2), f(n,2), xtrial(n,2)
  double precision :: ustep, ulast, dx, fnorm, random, potential, image

  ! Creating random initial coordinates

  i = 0
  do while( i < n )
    i = i + 1
    call random_number(random)
    x(i,1) = -side/2.d0 + side*random 
    call random_number(random)
    x(i,2) = -side/2.d0 + side*random 
  end do

  ! Minimizing the energy of the initial point

  ulast = potential(n,x)
  write(*,*) 'Energy before minimization: ', ulast

  dx = 1.d0
  fnorm = 1.d0
  do while( fnorm > 1.d-5 ) 

    ! Compute gradient

    call force(n,x,f)
    fnorm = 0.d0
    do i = 1, n
      fnorm = fnorm + f(i,1)**2 + f(i,2)**2
    end do
    fnorm = fnorm / n

    ! Compute trial point ( xtrial = x - (dU/dx)*dx )

    do i = 1, n
      xtrial(i,1) = x(i,1) + f(i,1)*dx
      xtrial(i,2) = x(i,2) + f(i,2)*dx
      xtrial(i,1) = image(xtrial(i,1))
      xtrial(i,2) = image(xtrial(i,2))
    end do
    ustep = potential(n,xtrial)

    ! If energy decreased, accept, if not, reject and decrease dx

    if ( ustep < ulast ) then
      do i = 1, n
        x(i,1) = xtrial(i,1)
        x(i,2) = xtrial(i,2)
      end do
      ulast = ustep
      dx = dx * 2.d0
    else
      dx = dx / 2.d0      
    end if
  end do

  write(*,*) 'Energy after minimization: ', potential(n,x)   

end subroutine initial
